# -*- coding: utf-8 -*-
from setuphelpers import *

# Please note that this is the last version of Java Runtime Environment (JRE) under OTN License that mean that you can ONLY use for free for personal or development use.
# More info here : https://blogs.oracle.com/java-platform-group/oracle-java-se-releases-faq
# Installation procedure: https://docs.oracle.com/javase/8/docs/technotes/guides/install/windows_installer_options.html
"""
UninstallKey                           Software                                                              Version             Uninstallstring
-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
{26A24AE4-039D-4CA4-87B4-2F64180xxxF0} Java 8 Update xxx (64-bit)                                            8.0.xxx0.9          MsiExec.exe /X{26A24AE4-039D-4CA4-87B4-2F64180xxxF0}
{26A24AE4-039D-4CA4-87B4-2F32180xxxF0} Java 8 Update xxx                                                     8.0.xxx0.9          MsiExec.exe /X{26A24AE4-039D-4CA4-87B4-2F32180xxxF0}
{4A03706F-666A-4037-7777-5F2748764D10} Java Auto Updater                                                     2.8.xxx.8
"""

# Defining variables
bin_name_string_x86 = "jre-8u%s-windows-i586.exe"
bin_name_string_x64 = "jre-8u%s-windows-x64.exe"
silent_inst_args_string = 'INSTALLCFG="%s" /s'
uninstall_key_string_x86 = "{71124AE4-039E-4CA4-87B4-2F32180%sF0}"
uninstall_key_string_x64 = "{71124AE4-039E-4CA4-87B4-2F64180%sF0}"


def install():
    # Initializing variables
    package_version = control.get_software_version()
    short_version = package_version.split("8.0.")[1]
    java_cfg = makepath(basedir, "java.cfg")
    processes_to_kill = control.impacted_process.split(",")
    install_dir_x86 = makepath(programfiles32, "Java", "jre1.8.0_%s" % short_version)
    install_dir_x64 = makepath(programfiles64, "Java", "jre1.8.0_%s" % short_version)

    # Uninstalling Olders / Others Java 8 versions
    check_installed = installed_softwares(name="Java 8")
    for uninstall_java in check_installed:
        if "Oracle" in uninstall_java["publisher"]:
            if uninstall_java["version"] < package_version:
                print("Removing %s" % uninstall_java["name"])
                run(uninstall_cmd(uninstall_java["key"]))

    # Removing remaining folders to avoid errors
    if need_install(uninstall_key_string_x86 % short_version):
        if isdir(install_dir_x86):
            killalltasks(processes_to_kill)
            remove_tree(install_dir_x86)
    if iswin64():
        if need_install(uninstall_key_string_x64 % short_version):
            if isdir(install_dir_x64):
                killalltasks(processes_to_kill)
                remove_tree(install_dir_x64)

    # Installing Java 8
    print("Installing: %s" % bin_name_string_x86 % short_version)
    install_exe_if_needed(
        bin_name_string_x86 % short_version, silentflags=silent_inst_args_string % java_cfg, key=uninstall_key_string_x86 % short_version
    )

    if iswin64():
        print("Installing: %s" % bin_name_string_x64 % short_version)
        install_exe_if_needed(
            bin_name_string_x64 % short_version, silentflags=silent_inst_args_string % java_cfg, key=uninstall_key_string_x64 % short_version
        )

    # Uninstalling Java Updater
    check_installed_updater = installed_softwares(name="Java Auto Updater")
    for uninstall_updater in check_installed_updater:
        print("Removing: %s" % uninstall_updater["name"])
        run(uninstall_cmd(uninstall_updater["key"]))

    # Disabling Automatic Updates and removing SunJavaUpdateSched startup key
    print("Disabling: Automatic Java Updates")
    if iswin64():
        registry_delete(HKEY_LOCAL_MACHINE, r"SOFTWARE\WOW6432Node\Microsoft\Windows\CurrentVersion\Run", "SunJavaUpdateSched")
        registry_setstring(HKEY_LOCAL_MACHINE, r"SOFTWARE\Wow6432Node\JavaSoft\Java Update\Policy", "EnableJavaUpdate", 0, type=REG_DWORD)
    registry_delete(HKEY_LOCAL_MACHINE, r"SOFTWARE\Microsoft\Windows\CurrentVersion\Run", "SunJavaUpdateSched")
    registry_setstring(HKEY_LOCAL_MACHINE, r"SOFTWARE\JavaSoft\Java Update\Policy", "EnableJavaUpdate", 0, type=REG_DWORD)
